# Contributing to PAROS

Thank you for considering contributing to PAROS! Before contributing, please read these guidelines, so we can process
your contribution as quickly as possible.

## Contribution ideas

We aim to make usage of the PAROS method as easy as possible by providing the code open-source in our Git repository. Any contributions serving this goal are welcome. For example, the addition of calibration experiments for other cameras than already provided could be added.

## Code style

- Please format your docstrings according to [numpydoc](https://numpydoc.readthedocs.io/en/latest/format.html).

## Workflow

### 1. Add your new feature

Add your contribution in a new feature branch. 

### 2. Open a Pull Request

Open a Pull Request, wait for our suggestions, and get your contribution merged!
